EyeballSet

Struct EyeballSet 

pub struct EyeballSet<F, T, E> { /* private fields */ }
Implements the Happy Eyeballs algorithm for connecting to a set of addresses.

This algorithm is used to connect to a set of addresses in parallel, with a delay between each attempt. The first successful connection is returned.

When the timeout is not set, the algorithm will attempt to connect to only one address at a time.

To connect to all addresses simultaneously, set the timeout to zero.

Implementations

Source

impl<F, T, E> EyeballSet<F, T, E>

pub fn new(configuration: EyeballConfiguration) -> Self

Create a new EyeballSet with an optional timeout.

The timeout is the amount of time between individual connection attempts.

pub fn is_empty(&self) -> bool

Returns true if the set of tasks is empty.

pub fn len(&self) -> usize

Returns the number of tasks in the set.

pub fn push(&mut self, future: F)
where F: Future<Output = Result<T, E>>,

Push a future into the set of tasks.

Source

impl<F, T, E> EyeballSet<F, T, E>
where F: Future<Output = Result<T, E>>,

pub async fn finish(&mut self) -> Result<T, HappyEyeballsError<E>>

Finish the happy eyeballs algorithm, returning the first successful connection.