pub struct EyeballSet<F, T, E> { /* private fields */ }Expand description
Implements the Happy Eyeballs algorithm for connecting to a set of addresses.
This algorithm is used to connect to a set of addresses in parallel, with a delay between each attempt. The first successful connection is returned.
When the timeout is not set, the algorithm will attempt to connect to only
one address at a time.
To connect to all addresses simultaneously, set the timeout to zero.
Implementations
Sourceimpl<F, T, E> EyeballSet<F, T, E>
impl<F, T, E> EyeballSet<F, T, E>
Sourcepub fn new(configuration: EyeballConfiguration) -> Self
pub fn new(configuration: EyeballConfiguration) -> Self
Create a new EyeballSet with an optional timeout.
The timeout is the amount of time between individual connection attempts.
Sourceimpl<F, T, E> EyeballSet<F, T, E>
impl<F, T, E> EyeballSet<F, T, E>
Sourcepub async fn finish(&mut self) -> Result<T, HappyEyeballsError<E>>
pub async fn finish(&mut self) -> Result<T, HappyEyeballsError<E>>
Finish the happy eyeballs algorithm, returning the first successful connection.